@@ -66,8 +66,8 @@ namespace tnt
         { 0, "UNKNOWN" },
         { HTTP_CONTINUE, "Continue" },
         { HTTP_SWITCHING_PROTOCOLS, "Switching Protocols" },
-        { HTTP_OK, "OK" },
         { HTTP_PROCESSING, "Processing" },
+        { HTTP_OK, "OK" },
         { HTTP_CREATED, "Created" },
         { HTTP_ACCEPTED, "Accepted" },
         { HTTP_NON_AUTHORITATIVE, "Non-Authoritative Information" },
@@ -121,9 +121,6 @@ namespace tnt
     inline bool operator< (const HttpMsg& m1, const HttpMsg& m2)
     { return m1.statusCode < m2.statusCode; }
 
-    inline std::ostream& operator<< (std::ostream& out, const HttpMsg& msg)
-    { return out << msg.statusCode << ' ' << msg.statusText; }
-
   }
 
   HttpReturn::HttpReturn(unsigned returncode_)
@@ -184,9 +181,27 @@ namespace tnt
     return p == std::string::npos ? msg.substr(4) : msg.substr(4, p - 4);
   }
 
-  NotFoundException::NotFoundException(const std::string& url_)
-    : HttpError(HTTP_NOT_FOUND, "Not Found"),
-      url(url_)
+  namespace
+  {
+    std::string notFoundMsg(const std::string& url, const std::string& vhost)
+    {
+      std::string msg = "Not Found: ";
+      if (!vhost.empty())
+      {
+        msg += "vhost: ";
+        msg += vhost;
+        msg += ' ';
+      }
+
+      msg += url;
+      return msg;
+    }
+  }
+
+  NotFoundException::NotFoundException(const std::string& url_, const std::string& vhost_)
+    : HttpError(HTTP_NOT_FOUND, notFoundMsg(url_, vhost_)),
+      url(url_),
+      vhost(vhost_)
   {
   }
 
