@@ -1,26 +1,35 @@
-/* httpmessage.cpp
+/*
  * Copyright (C) 2003-2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
  */
 
 
 #include <tnt/httpmessage.h>
 #include <cxxtools/log.h>
-#include <cxxtools/thread.h>
+#include <cxxtools/mutex.h>
 #include <list>
 #include <sstream>
 #include <stdio.h>
@@ -30,8 +39,6 @@ namespace tnt
   ////////////////////////////////////////////////////////////////////////
   // HttpMessage
   //
-  log_define("tntnet.httpmessage")
-
   void HttpMessage::clear()
   {
     header.clear();
@@ -39,23 +46,12 @@ namespace tnt
     minorVersion = 0;
   }
 
-  std::string HttpMessage::getHeader(const std::string& key, const std::string& def) const
+  const char* HttpMessage::getHeader(const char* key, const char* def) const
   {
     header_type::const_iterator i = header.find(key);
     return i == header.end() ? def : i->second;
   }
 
-  void HttpMessage::setHeader(const std::string& key, const std::string& value, bool replace)
-  {
-    log_debug("HttpMessage::setHeader(\"" << key << "\", \"" << value << "\", " << replace << ')');
-    if (replace)
-      header.erase(key);
-    std::string k = key;
-    if (k.size() > 0 && k.at(k.size() - 1) != ':')
-      k += ':';
-    header.insert(header_type::value_type(k, value));
-  }
-
   std::string HttpMessage::dumpHeader() const
   {
     std::ostringstream h;
@@ -105,22 +101,19 @@ namespace tnt
 
     time_t t;
     time(&t);
-    time_t day = t / (24*60*60);
 
     cxxtools::MutexLock lock(mutex);
 
-    if (day != lastDay)
-    {
-      // Day differs, we calculate new date.
-
-      gmtime_r(&t, &lastTm);
-      lastDay = day;
-    }
-
     if (lastTime != t)
     {
-      // We can use the cached tm-struct and calculate hour, minute and
-      // seconds. No locking was needed at all. This is the common case.
+      time_t day = t / (24*60*60);
+      if (day != lastDay)
+      {
+        // Day differs, we calculate new date.
+        gmtime_r(&t, &lastTm);
+        lastDay = day;
+      }
+
       lastTm.tm_sec = t % 60;
       t /= 60;
       lastTm.tm_min = t % 60;
@@ -130,7 +123,9 @@ namespace tnt
       lastTime = t;
     }
 
-    return lastHtdate;
+    // we do a copy of lastHtdate first to make sure we have the lock
+    std::string ret = lastHtdate;
+    return ret;
   }
 
   namespace
