@@ -37,10 +37,10 @@ namespace tnt
   extern const std::string factorySuffix;
 
   class Component;
-  class Compident;
+  struct Compident;
   class Comploader;
   class Urlmapper;
-  class Tntconfig;
+  struct TntConfig;
 
   class ComponentFactory
   {
@@ -53,7 +53,7 @@ namespace tnt
     protected:
       virtual Component* doCreate(const tnt::Compident& ci,
         const tnt::Urlmapper& um, tnt::Comploader& cl) = 0;
-      virtual void doConfigure(const tnt::Tntconfig& config);
+      virtual void doConfigure(const tnt::TntConfig& config);
 
     public:
       ComponentFactory(const std::string& componentName_);
