@@ -1,20 +1,29 @@
-/* tnt/cookie.h
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
+ * 
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
  */
 
 
@@ -35,6 +44,8 @@ namespace tnt
   {
       friend std::ostream& operator<< (std::ostream& out, const Cookies& c);
       friend class CookieParser;
+      friend class HttpReply;
+      void write(std::ostream& out, const std::string& name) const;
 
     public:
       static const std::string maxAge;
@@ -83,6 +94,8 @@ namespace tnt
 
       void setAttr(const std::string& name, const std::string& value_)
         { attrs[name] = value_; }
+      bool hasAttr(const std::string& name) const
+        { return attrs.find(name) != attrs.end(); }
 
       unsigned    getMaxAge() const;
       std::string getComment() const { return getAttr(comment); }
@@ -99,12 +112,20 @@ namespace tnt
       void setVersion(const std::string& value_) { setAttr(version, value_); }
       void setExpires(const std::string& value_) { setAttr(expires, value_); }
       void setSecure(bool f = true)              { secureFlag = f; }
+
+      bool hasMaxAge() const                     { return hasAttr(maxAge); }
+      bool hasComment() const                    { return hasAttr(comment); }
+      bool hasDomain() const                     { return hasAttr(domain); }
+      bool hasPath() const                       { return hasAttr(path); }
+      bool hasVersion() const                    { return hasAttr(version); }
+      bool hasExpires() const                    { return hasAttr(expires); }
+
   };
 
   class Cookies
   {
       friend std::ostream& operator<< (std::ostream& out, const Cookies& c);
-      friend class cookie_parser;
+      friend class HttpReply;
 
       typedef std::map<std::string, Cookie, StringLessIgnoreCase<std::string> > cookies_type;
       cookies_type data;
