@@ -59,7 +59,7 @@ namespace tnt
       ~PointerObject()
         { destroyPolicy<data_type>::destroy(ptr); }
       void set(data_type* ptr_)
-        { destroy(ptr); ptr = ptr_; }
+        { destroyPolicy<data_type>::destroy(ptr); ptr = ptr_; }
       data_type* get()  { return ptr; }
   };
 
