@@ -1,20 +1,29 @@
-/* subcomponent.cpp
+/*
  * Copyright (C) 2005 Tommi Maekitalo
- *
- * This program is free software; you can redistribute it and/or
+ * 
+ * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * 
+ * As a special exception, you may use this file as part of a free
+ * software library without restriction. Specifically, if other files
+ * instantiate templates or use macros or inline functions from this
+ * file, or you compile this file and link it with other files to
+ * produce an executable, this file does not by itself cause the
+ * resulting executable to be covered by the GNU General Public
+ * License. This exception does not however invalidate any other
+ * reasons why the executable file might be covered by the GNU Library
+ * General Public License.
+ * 
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
- *
+ * 
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
+ * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
  */
 
 
@@ -31,10 +40,10 @@ namespace tnt
     {
       o << "    class " << getName() << "_type : public tnt::EcppSubComponent\n"
            "    {\n"
-           "        _component_" << outerclass->getName() << "& mainComp;\n"
-           "        _component_" << outerclass->getName() << "& main()  { return mainComp; }\n\n"
+           "        _component_& mainComp;\n"
+           "        _component_& main()  { return mainComp; }\n\n"
            "      public:\n"
-           "        " << getName() << "_type(_component_" << outerclass->getName() << "& m, const std::string& name)\n"
+           "        " << getName() << "_type(_component_& m, const std::string& name)\n"
            "          : EcppSubComponent(m, name),\n"
            "            mainComp(m)\n"
            "          { }\n"
@@ -50,18 +59,16 @@ namespace tnt
            "    };\n\n";
     }
 
-    void Subcomponent::getDefinition(std::ostream& code, bool debug, bool externData, bool linenumbersEnabled) const
+    void Subcomponent::getDefinition(std::ostream& code, bool externData, bool linenumbersEnabled) const
     {
-      code << "unsigned _component_" << outerclass->getName() << "::" << getName()
+      code << "unsigned _component_::" << getName()
            << "_type::operator() (tnt::HttpRequest& request, tnt::HttpReply& reply, tnt::QueryParams& qparam";
       for (cppargs_type::const_iterator j = cppargs.begin();
            j != cppargs.end(); ++j)
         code << ", " << j->first;
       code << ")\n"
-              "{\n";
-
-      if (debug)
-        code << "  log_trace(\"" << outerclass->getName() << "::" << getName() << " \" << qparam.getUrl());\n";
+              "{\n"
+              "  log_trace(\"" << outerclass->getName() << "::" << getName() << " \" << qparam.getUrl());\n";
 
       if (externData)
         code << "  tnt::DataChunks data(getData(request, rawData));\n";
